==> kibot-1.6.4.tar.gz: kibot-1.6.4/README.md <==
# KiBot (formerly KiPlot)

![KiBot Logo](https://raw.githubusercontent.com/INTI-CMNB/KiBot/master/docs/images/kibot_740x400_logo.png)

[![Python application](https://img.shields.io/github/actions/workflow/status/INTI-CMNB/KiBot/pythonapp.yml?branch=master&style=plastic&logo=github)](https://github.com/INTI-CMNB/KiBot/actions)
[![Coverage Status](https://img.shields.io/coveralls/github/INTI-CMNB/KiBot?style=plastic&logo=coveralls&branch=master)](https://coveralls.io/github/INTI-CMNB/KiBot?branch=dev)
[![PyPI version](https://img.shields.io/pypi/v/kibot?style=plastic&logo=pypi)](https://pypi.org/project/kibot/)
[![DOCs status](https://img.shields.io/readthedocs/kibot?style=plastic&logo=readthedocs)](https://kibot.readthedocs.io/en/stable/)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg?style=plastic&logo=paypal)](https://www.paypal.com/donate/?hosted_button_id=K2T86GDTTMRPL)

KiBot is a program which helps you to generate the fabrication and
documentation files for your KiCad projects easily, repeatable, and most
of all, scriptably. This means you can use a Makefile to export your
KiCad PCBs just as needed, or do it in a CI/CD environment.

For more information consult the [documentation](https://kibot.readthedocs.io/en/stable/) (hosted by Read the Docs)

If you are looking for the last features and fixes visit the [dev branch](https://github.com/INTI-CMNB/KiBot/tree/dev)

If you want to see an example of what KiBot can generate visit this
[project](https://inti-cmnb.github.io/kibot_variants_arduprog_site/Browse/t1-navigate.html)

==> kibot-1.8.0.tar.gz: kibot-1.8.0/README.md <==
# KiBot (formerly KiPlot)

![KiBot Logo](https://raw.githubusercontent.com/INTI-CMNB/KiBot/master/docs/images/kibot_740x400_logo.png)

[![Python application](https://img.shields.io/github/actions/workflow/status/INTI-CMNB/KiBot/pythonapp.yml?branch=master&style=plastic&logo=github)](https://github.com/INTI-CMNB/KiBot/actions)
[![Coverage Status](https://img.shields.io/coveralls/github/INTI-CMNB/KiBot?style=plastic&logo=coveralls&branch=master)](https://coveralls.io/github/INTI-CMNB/KiBot?branch=dev)
[![PyPI version](https://img.shields.io/pypi/v/kibot?style=plastic&logo=pypi)](https://pypi.org/project/kibot/)
[![DOCs status](https://img.shields.io/readthedocs/kibot?style=plastic&logo=readthedocs)](https://kibot.readthedocs.io/en/stable/)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg?style=plastic&logo=paypal)](https://www.paypal.com/donate/?hosted_button_id=K2T86GDTTMRPL)

KiBot is a program which helps you to generate the fabrication and
documentation files for your KiCad projects easily, repeatable, and most
of all, scriptably. This means you can use a Makefile to export your
KiCad PCBs just as needed, or do it in a CI/CD environment.

For more information consult the [documentation](https://kibot.readthedocs.io/en/master/) (hosted by Read the Docs)

If you are looking for the last features and fixes visit the [dev branch](https://github.com/INTI-CMNB/KiBot/tree/dev)

If you want to see an example of what KiBot can generate visit this
[project](https://inti-cmnb.github.io/kibot_variants_arduprog_site/Browse/t1-navigate.html)
